<?php
/**
 * Ad Management Tab
 *
 * @package Fresh
 */

$menus['ad-management'] = array(
	'icon'  => 'fa-bar-chart-o',
	'title' => esc_html__( 'Ad Management', 'fresh' ),
	'desc'  => esc_html__( 'Now, ad management is easy with our options panel. You can control everything from here, without using separate plugins.', 'fresh' ),
);

// Dependency check that detect ad blocker option is enable.
$detect_adblocker = [
	'relation' => 'and',
	[
		'field'      => 'detect_adblocker',
		'value'      => '1',
		'comparison' => '==',
	],
];

// Dependency check that background clickable option is enable.
$background_clickable = [
	'relation' => 'and',
	[
		'field'      => 'background_clickable',
		'value'      => '1',
		'comparison' => '==',
	],
];

// Dependency check that navigation ad option is enable.
$navigation_ad = [
	'relation' => 'and',
	[
		'field'      => 'navigation_ad',
		'value'      => '1',
		'comparison' => '==',
	],
];

$sections['ad-management'] = array(

	array(
		'id'       => 'detect_adblocker',
		'type'     => 'switch',
		'title'    => esc_html__( 'Detect Ad Blocker', 'fresh' ),
		'sub_desc' => esc_html__( 'If user is using any ad blocker extension then this option will hide the content and will ask user to white-list your website.', 'fresh' ),
		'std'      => '0',
	),

	array(
		'id'         => 'detect_adblocker_type',
		'type'       => 'button_set',
		'title'      => esc_html__( 'Ad Blocker Notice Type', 'fresh' ),
		'class'      => 'green',
		'options'    => array(
			'hide-content' => esc_html__( 'Hide Content', 'fresh' ),
			'popup'        => esc_html__( 'Show Popup', 'fresh' ),
			'floating'     => esc_html__( 'Floating Notice', 'fresh' ),
			'shortcode'    => esc_html__( 'Shortcode', 'fresh' ),
		),
		// translators: Ad Blocker title description.
		'sub_desc'   => sprintf( __( 'Choose Ad Blocker Notice type from here. SHORTCODE: %s ', 'fresh' ), '<code>[detect_adblocker title="Your Title" description="Description"]Content[/detect_adblocker]</code>' ),
		'std'        => 'popup',
		'dependency' => $detect_adblocker,
	),
	array(
		'id'         => 'detect_adblocker_title',
		'type'       => 'text',
		'title'      => esc_html__( 'Ad Blocker Title', 'fresh' ),
		'sub_desc'   => esc_html__( 'Enter Ad Blocker detector Title here.', 'fresh' ),
		'std'        => esc_html__( 'Ad Blocker Detected', 'fresh' ),
		'dependency' => $detect_adblocker,
	),
	array(
		'id'         => 'detect_adblocker_description',
		'type'       => 'textarea',
		'title'      => esc_html__( 'Ad Blocker Description', 'fresh' ),
		'sub_desc'   => esc_html__( 'Enter Ad Blocker detector Description here.', 'fresh' ),
		'std'        => esc_html__( 'Our website is made possible by displaying online advertisements to our visitors. Please consider supporting us by disabling your ad blocker.', 'fresh' ),
		'dependency' => $detect_adblocker,
	),
	array(
		'id'       => 'background_clickable',
		'type'     => 'switch',
		'title'    => esc_html__( 'Site Background Clickable', 'fresh' ),
		'sub_desc' => esc_html__( 'This option will make your website background clickable.', 'fresh' ),
		'std'      => '0',
	),
	array(
		'id'         => 'background_link',
		'type'       => 'text',
		'title'      => esc_html__( 'Site Background URL', 'fresh' ),
		'sub_desc'   => esc_html__( 'Enter URL Here', 'fresh' ),
		'validate'   => 'url',
		'dependency' => $background_clickable,
	),
	array(
		'id'         => 'background_link_new_tab',
		'type'       => 'switch',
		'title'      => esc_html__( 'Site Background Click - Open in new Tab', 'fresh' ),
		'sub_desc'   => esc_html__( 'Enable this option to open link in a new tab.', 'fresh' ),
		'std'        => '1',
		'dependency' => $background_clickable,
	),

	array(
		'id'       => 'mts_header_adcode',
		'type'     => 'ace_editor',
		'mode'     => 'html',
		'title'    => esc_html__( 'Header Ad', 'fresh' ),
		'sub_desc' => esc_html__( 'Paste your Adsense, BSA or other ad code here to show ads in Header Area.', 'fresh' ),
	),
	array(
		'id'       => 'header_adcode_show',
		'type'     => 'button_set',
		'title'    => esc_html__( 'Header Adcode Show on', 'fresh' ),
		'sub_desc' => esc_html__( 'Choose where you want to show the header adcode', 'fresh' ),
		'options'  => array(
			'all'    => esc_html__( 'All Pages', 'fresh' ),
			'home'   => esc_html__( 'Home Page', 'fresh' ),
			'single' => esc_html__( 'Single Post', 'fresh' ),
			'page'   => esc_html__( 'Pages', 'fresh' ),
		),
		'std'      => 'all',
	),
	array(
		'id'       => 'header_ad_size',
		'type'     => 'select',
		'title'    => esc_html__( 'Header Ad Size [For Adsense Ads]', 'fresh' ),
		'sub_desc' => esc_html__( 'If you leave the AdSense size boxes on Auto, the theme will automatically resize the Google ads. Note: For smaller screens ads will be set on Auto mode irrespective of size defined here.', 'fresh' ),
		'options'  => ad_sizes(),
		'std'      => '0',
	),
	array(
		'id'       => 'mts_header_adcode_margin',
		'type'     => 'margin',
		'title'    => esc_html__( 'Header Ad Margin', 'fresh' ),
		'sub_desc' => esc_html__( 'Set header ad margin from here.', 'fresh' ),
		'left'     => false,
		'right'    => false,
		'std'      => array(
			'top'    => '0',
			'bottom' => '0',
		),
	),

	array(
		'id'       => 'navigation_ad',
		'type'     => 'switch',
		'title'    => esc_html__( 'Navigation Ad', 'fresh' ),
		'sub_desc' => esc_html__( 'This option will let you add an Ad below Navigation menu.', 'fresh' ),
		'std'      => '0',
	),
	array(
		'id'         => 'navigation_adcode',
		'type'       => 'ace_editor',
		'mode'       => 'html',
		'title'      => esc_html__( 'Navigation Ad Code', 'fresh' ),
		'sub_desc'   => esc_html__( 'Paste your Adsense, BSA or other ad code here to show ads in the Header.', 'fresh' ),
		'dependency' => $navigation_ad,
	),
	array(
		'id'         => 'navigation_ad_size',
		'type'       => 'select',
		'title'      => esc_html__( 'Navigation Ad Size [For Adsense Ads]', 'fresh' ),
		'sub_desc'   => esc_html__( 'If you leave the AdSense size boxes on Auto, the theme will automatically resize the Google ads. Note: For smaller screens ads will be set on Auto mode irrespective of size defined here.', 'fresh' ),
		'options'    => ad_sizes(),
		'std'        => '26',
		'dependency' => $navigation_ad,
	),
	array(
		'id'         => 'navigation_ad_background',
		'type'       => 'color',
		'title'      => esc_html__( 'Navigation Ad Background', 'fresh' ),
		'sub_desc'   => esc_html__( 'Set background color for navigation Ad from here.', 'fresh' ),
		'std'        => '#252525',
		'dependency' => $navigation_ad,
	),

	array(
		'id'       => 'mts_postfooter_adcode',
		'type'     => 'ace_editor',
		'mode'     => 'html',
		'title'    => esc_html__( 'Before Footer', 'fresh' ),
		'sub_desc' => esc_html__( 'Paste your Adsense, BSA or other ad code here to show ads before footer.', 'fresh' ),
	),
	array(
		'id'       => 'mts_postfooter_adcode_time',
		'type'     => 'text',
		'title'    => esc_html__( 'Show After X Days', 'fresh' ),
		'sub_desc' => esc_html__( 'Enter the number of days after which you want to show the before footer. Enter 0 to disable this feature.', 'fresh' ),
		'validate' => 'numeric',
		'std'      => '0',
		'class'    => 'small-text',
		'args'     => array( 'type' => 'number' ),
	),
	array(
		'id'       => 'mts_posttop_adcode',
		'type'     => 'ace_editor',
		'mode'     => 'html',
		'title'    => esc_html__( 'Below Post Title', 'fresh' ),
		'sub_desc' => esc_html__( 'Paste your Adsense, BSA or other ad code here to show ads below your article title on single posts.', 'fresh' ),
	),
	array(
		'id'       => 'mts_posttop_adcode_time',
		'type'     => 'text',
		'title'    => esc_html__( 'Show After X Days', 'fresh' ),
		'sub_desc' => esc_html__( 'Enter the number of days after which you want to show the Below Post Title Ad. Enter 0 to disable this feature.', 'fresh' ),
		'validate' => 'numeric',
		'std'      => '0',
		'class'    => 'small-text',
		'args'     => array( 'type' => 'number' ),
	),
	array(
		'id'       => 'mts_postend_adcode',
		'type'     => 'ace_editor',
		'mode'     => 'html',
		'title'    => esc_html__( 'Below Post Content', 'fresh' ),
		'sub_desc' => esc_html__( 'Paste your Adsense, BSA or other ad code here to show ads below the post content on single posts.', 'fresh' ),
	),
	array(
		'id'       => 'mts_postend_adcode_time',
		'type'     => 'text',
		'title'    => esc_html__( 'Show After X Days', 'fresh' ),
		'sub_desc' => esc_html__( 'Enter the number of days after which you want to show the Below Post Title Ad. Enter 0 to disable this feature.', 'fresh' ),
		'validate' => 'numeric',
		'std'      => '0',
		'class'    => 'small-text',
		'args'     => array( 'type' => 'number' ),
	),
);
