<?php
/**
 * HomePage Posts
 *
 * @package Fresh
 */

$features = fresh_get_settings( 'mts_featured_categories' );
if ( empty( $features ) ) {
	return;
}
foreach ( $features as $feature ) :
	$title        = isset( $feature['mts_featured_title'] ) ? $feature['mts_featured_title'] : 'No Title';
	$posts_layout = isset( $feature['blog_layout'] ) ? $feature['blog_layout'] : '';
	if ( 'layout-default' === $posts_layout ) {
		$posts_layout = 'default';
	}
	$unique_id = isset( $feature['unique_id'] ) ? $feature['unique_id'] : '';

	$menus['blog']['child'][ 'blog-' . $unique_id ] = array(
		'title' => $title,
		// translators: description.
		'desc'  => sprintf( wp_kses_post( __( 'From here, you can control the elements of %s', 'fresh' ) ), $title ),
	);

	// Dependency check that back to top option is enable.
	$post_title_dependency = array(
		'relation' => 'and',
		array(
			'field'      => 'mts_featured_category_title_' . $unique_id,
			'value'      => '1',
			'comparison' => '==',
		),
	);

	$sections[ 'blog-' . $unique_id ] = array(

		/**
		 * Layout Default Settings
		 *
		 * @package Fresh
		 */

		// Section Title.
		( 'default' === $posts_layout ) ? array(
			'id'    => 'mts_post_title_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Section Title', 'fresh' ),
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'       => 'mts_featured_category_title_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Show/Hide Title', 'fresh' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide title of post container.', 'fresh' ),
			'std'      => '1',
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'         => 'mts_post_title_alignment_' . $unique_id,
			'type'       => 'button_set',
			'title'      => esc_html__( 'Section Title Alignment', 'fresh' ),
			'sub_desc'   => esc_html__( 'Choose the section title alignment', 'fresh' ),
			'options'    => array(
				'left'   => esc_html__( 'Left', 'fresh' ),
				'center' => esc_html__( 'Center', 'fresh' ),
				'right'  => esc_html__( 'Right', 'fresh' ),
			),
			'std'        => 'left',
			'dependency' => $post_title_dependency,
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'         => 'mts_featured_category_title_background_' . $unique_id,
			'type'       => 'background',
			'title'      => esc_html__( 'Post Title Background Color', 'fresh' ),
			'sub_desc'   => esc_html__( 'Set background color, pattern and image from here.', 'fresh' ),
			'options'    => array(
				'color'         => '',            // false to disable, not needed otherwise.
				'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
				'image_upload'  => '',            // false to disable, not needed otherwise.
				'repeat'        => array(),       // false to disable, array of options to override default ( optional ).
				'attachment'    => array(),       // false to disable, array of options to override default ( optional ).
				'position'      => array(),       // false to disable, array of options to override default ( optional ).
				'size'          => array(),       // false to disable, array of options to override default ( optional ).
				'gradient'      => '',            // false to disable, not needed otherwise.
				'parallax'      => array(),       // false to disable, array of options to override default ( optional ).
			),
			'std'        => array(
				'color'         => '',
				'use'           => 'pattern',
				'image_pattern' => 'nobg',
				'image_upload'  => '',
				'repeat'        => 'repeat',
				'attachment'    => 'scroll',
				'position'      => 'left top',
				'size'          => 'cover',
				'gradient'      => array(
					'from'      => '#ffffff',
					'to'        => '#000000',
					'direction' => '0deg',
				),
				'parallax'      => '0',
			),
			'dependency' => $post_title_dependency,
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'         => 'mts_featured_category_title_margin_' . $unique_id,
			'type'       => 'margin',
			'title'      => esc_html__( 'Post Title Margin', 'fresh' ),
			'sub_desc'   => esc_html__( 'Set section title margin from here.', 'fresh' ),
			'std'        => array(
				'top'    => '0',
				'right'  => '0',
				'bottom' => '40px',
				'left'   => '0',
			),
			'dependency' => $post_title_dependency,
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'         => 'mts_featured_category_title_padding_' . $unique_id,
			'type'       => 'margin',
			'title'      => esc_html__( 'Post Title Padding', 'fresh' ),
			'sub_desc'   => esc_html__( 'Set section title padding from here.', 'fresh' ),
			'std'        => array(
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
				'left'   => '0',
			),
			'dependency' => $post_title_dependency,
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'         => 'post_title_border_' . $unique_id,
			'type'       => 'border',
			'title'      => esc_html__( 'Border', 'fresh' ),
			'sub_desc'   => esc_html__( 'Select border', 'fresh' ),
			'dependency' => $post_title_dependency,
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'         => 'mts_featured_category_title_font_' . $unique_id,
			'type'       => 'typography',
			'title'      => esc_html__( 'Section Title Typography', 'fresh' ),
			'std'        => array(
				'preview-text'   => 'Title Font',
				'preview-color'  => 'light',
				'font-family'    => 'Open Sans',
				'font-weight'    => '700',
				'font-size'      => '22px',
				'color'          => '#494b46',
				'additional-css' => 'text-transform: uppercase;',
				'css-selectors'  => '.title-container.title-id-' . $unique_id . ' h3.featured-category-title',
			),
			'dependency' => $post_title_dependency,
		) : null,

		// Meta info.
		( 'default' === $posts_layout ) ? array(
			'id'    => 'post_meta_info_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Meta Info', 'fresh' ),
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'       => 'mts_home_headline_meta_info' . $unique_id,
			'type'     => 'layout2',
			// translators: title.
			'title'    => sprintf( wp_kses_post( __( '%s Meta Info', 'fresh' ) ), $title ),
			// translators: description.
			'sub_desc' => sprintf( wp_kses_post( __( 'Organize how you want the post meta info to appear on %s', 'fresh' ) ), $title ),
			'options'  => array(
				'enabled'  => array(
					'date'    => array(
						'label'     => esc_html__( 'Date', 'fresh' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_date_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'fresh' ),
							),
						),
					),
					'comment' => array(
						'label'     => esc_html__( 'Comment Count', 'fresh' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_comment_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'fresh' ),
							),
						),
					),
				),
				'disabled' => array(
					'author'   => array(
						'label'     => __( 'Author Name', 'fresh' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_author_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'fresh' ),
							),
						),
					),
					'category' => array(
						'label'     => esc_html__( 'Categories', 'fresh' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_category_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'fresh' ),
							),
						),
					),
				),
			),
			'std'      => array(
				'enabled'  => array(
					'date'    => array(
						'label'     => esc_html__( 'Date', 'fresh' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_date_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'fresh' ),
							),
						),
					),
					'comment' => array(
						'label'     => esc_html__( 'Comment Count', 'fresh' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_comment_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'fresh' ),
							),
						),
					),
				),
				'disabled' => array(
					'author'   => array(
						'label'     => __( 'Author Name', 'fresh' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_author_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'fresh' ),
							),
						),
					),
					'category' => array(
						'label'     => esc_html__( 'Categories', 'fresh' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_category_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'fresh' ),
							),
						),
					),
				),
			),
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'       => 'mts_meta_info_margin_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Margin', 'fresh' ),
			'sub_desc' => esc_html__( 'Post Meta Info margin.', 'fresh' ),
			'std'      => array(
				'top'    => '6px',
				'right'  => '0',
				'bottom' => '0',
				'left'   => '0',
			),
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'       => 'mts_meta_info_padding_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Padding', 'fresh' ),
			'sub_desc' => esc_html__( 'Post Meta Info padding.', 'fresh' ),
			'std'      => array(
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
				'left'   => '0',
			),
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'       => 'meta_info_border_' . $unique_id,
			'type'     => 'border',
			'title'    => esc_html__( 'Border', 'fresh' ),
			'sub_desc' => esc_html__( 'Select border.', 'fresh' ),
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'    => 'meta_info_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Meta Info Typography', 'fresh' ),
			'std'   => array(
				'preview-text'  => 'Post Meta Info Font',
				'preview-color' => 'light',
				'font-family'   => 'Open Sans',
				'font-weight'   => '400',
				'font-size'     => '15px',
				'color'         => '#8e8c8c',
				'css-selectors' => '.layout-' . $unique_id . ' .latestPost .post-info, .layout-' . $unique_id . ' .latestPost .post-info span a',
			),
		) : null,
		// Post Container.
		( 'default' === $posts_layout ) ? array(
			'id'    => 'mts_post_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Container', 'fresh' ),
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'       => 'readmore_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Enable/Disable Read More', 'fresh' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide readmore.', 'fresh' ),
			'std'      => '1',
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'       => 'mts_featured_category_background_' . $unique_id,
			'type'     => 'background',
			'title'    => esc_html__( 'Post Background Color', 'fresh' ),
			'sub_desc' => esc_html__( 'Set background color, pattern and image from here.', 'fresh' ),
			'options'  => array(
				'color'         => '',            // false to disable, not needed otherwise.
				'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
				'image_upload'  => '',            // false to disable, not needed otherwise.
				'repeat'        => array(),       // false to disable, array of options to override default ( optional ).
				'attachment'    => array(),       // false to disable, array of options to override default ( optional ).
				'position'      => array(),       // false to disable, array of options to override default ( optional ).
				'size'          => array(),       // false to disable, array of options to override default ( optional ).
				'gradient'      => '',            // false to disable, not needed otherwise.
				'parallax'      => array(),       // false to disable, array of options to override default ( optional ).
			),
			'std'      => array(
				'color'         => '',
				'use'           => 'pattern',
				'image_pattern' => 'nobg',
				'image_upload'  => '',
				'repeat'        => 'repeat',
				'attachment'    => 'scroll',
				'position'      => 'left top',
				'size'          => 'cover',
				'gradient'      => array(
					'from'      => '#ffffff',
					'to'        => '#000000',
					'direction' => '0deg',
				),
				'parallax'      => '0',
			),
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'       => 'post_border_' . $unique_id,
			'type'     => 'border',
			'title'    => esc_html__( 'Border', 'fresh' ),
			'sub_desc' => esc_html__( 'Select border', 'fresh' ),
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'       => 'post_margin_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Margin', 'fresh' ),
			'sub_desc' => esc_html__( 'Post margin.', 'fresh' ),
			'left'     => false,
			'right'    => false,
			'std'      => array(
				'top'    => '34px',
				'bottom' => '35px',
			),
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'       => 'post_padding_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Padding', 'fresh' ),
			'sub_desc' => esc_html__( 'Post padding.', 'fresh' ),
			'std'      => array(
				'left'   => '0',
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
			),
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'    => 'post_title_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Title Font', 'fresh' ),
			'std'   => array(
				'preview-text'  => 'Post Title Font',
				'preview-color' => 'light',
				'font-family'   => 'Open Sans',
				'font-weight'   => '600',
				'font-size'     => '28px',
				'line-height'   => '42px',
				'color'         => '#444444',
				'css-selectors' => '.layout-' . $unique_id . ' .latestPost .title a',
			),
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'    => 'post_excerpt_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Excerpt Font', 'fresh' ),
			'std'   => array(
				'preview-text'  => 'Post Excerpt Font',
				'preview-color' => 'light',
				'font-family'   => 'Open Sans',
				'font-weight'   => '400',
				'font-size'     => '16px',
				'line-height'   => '27px',
				'color'         => '#444444',
				'css-selectors' => '.layout-' . $unique_id . ' .latestPost .front-view-content',
			),
		) : null,

		/**
		 * Layout Featured Settings
		 *
		 * @package Fresh
		 */

		// Section Title.
		( 'layout-featured' === $posts_layout ) ? array(
			'id'    => 'mts_post_title_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Section Title', 'fresh' ),
		) : null,

		( 'layout-featured' === $posts_layout ) ? array(
			'id'       => 'mts_featured_category_title_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Show/Hide Title', 'fresh' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide title of post container.', 'fresh' ),
			'std'      => '1',
		) : null,

		( 'layout-featured' === $posts_layout ) ? array(
			'id'         => 'view_more_' . $unique_id,
			'type'       => 'switch',
			'title'      => esc_html__( 'View More', 'fresh' ),
			'sub_desc'   => esc_html__( 'Use this button to show or hide view more link.', 'fresh' ),
			'std'        => '1',
			'dependency' => $post_title_dependency,
		) : null,

		( 'layout-featured' === $posts_layout ) ? array(
			'id'         => 'mts_post_title_alignment_' . $unique_id,
			'type'       => 'button_set',
			'title'      => esc_html__( 'Section Title Alignment', 'fresh' ),
			'sub_desc'   => esc_html__( 'Choose the section title alignment', 'fresh' ),
			'options'    => array(
				'left'   => esc_html__( 'Left', 'fresh' ),
				'center' => esc_html__( 'Center', 'fresh' ),
				'right'  => esc_html__( 'Right', 'fresh' ),
			),
			'std'        => 'left',
			'dependency' => $post_title_dependency,
		) : null,
		( 'layout-featured' === $posts_layout ) ? array(
			'id'         => 'mts_featured_category_title_background_' . $unique_id,
			'type'       => 'background',
			'title'      => esc_html__( 'Post Title Background Color', 'fresh' ),
			'sub_desc'   => esc_html__( 'Set background color, pattern and image from here.', 'fresh' ),
			'options'    => array(
				'color'         => '',            // false to disable, not needed otherwise.
				'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
				'image_upload'  => '',            // false to disable, not needed otherwise.
				'repeat'        => array(),       // false to disable, array of options to override default ( optional ).
				'attachment'    => array(),       // false to disable, array of options to override default ( optional ).
				'position'      => array(),       // false to disable, array of options to override default ( optional ).
				'size'          => array(),       // false to disable, array of options to override default ( optional ).
				'gradient'      => '',            // false to disable, not needed otherwise.
				'parallax'      => array(),       // false to disable, array of options to override default ( optional ).
			),
			'std'        => array(
				'color'         => '',
				'use'           => 'pattern',
				'image_pattern' => 'nobg',
				'image_upload'  => '',
				'repeat'        => 'repeat',
				'attachment'    => 'scroll',
				'position'      => 'left top',
				'size'          => 'cover',
				'gradient'      => array(
					'from'      => '#ffffff',
					'to'        => '#000000',
					'direction' => '0deg',
				),
				'parallax'      => '0',
			),
			'dependency' => $post_title_dependency,
		) : null,
		( 'layout-featured' === $posts_layout ) ? array(
			'id'         => 'mts_featured_category_title_margin_' . $unique_id,
			'type'       => 'margin',
			'title'      => esc_html__( 'Post Title Margin', 'fresh' ),
			'sub_desc'   => esc_html__( 'Set section title margin from here.', 'fresh' ),
			'std'        => array(
				'top'    => '0',
				'right'  => '0',
				'bottom' => '28px',
				'left'   => '0',
			),
			'dependency' => $post_title_dependency,
		) : null,
		( 'layout-featured' === $posts_layout ) ? array(
			'id'         => 'mts_featured_category_title_padding_' . $unique_id,
			'type'       => 'margin',
			'title'      => esc_html__( 'Post Title Padding', 'fresh' ),
			'sub_desc'   => esc_html__( 'Set section title padding from here.', 'fresh' ),
			'std'        => array(
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
				'left'   => '0',
			),
			'dependency' => $post_title_dependency,
		) : null,
		( 'layout-featured' === $posts_layout ) ? array(
			'id'         => 'post_title_border_' . $unique_id,
			'type'       => 'border',
			'title'      => esc_html__( 'Border', 'fresh' ),
			'sub_desc'   => esc_html__( 'Select border', 'fresh' ),
			'dependency' => $post_title_dependency,
		) : null,

		( 'layout-featured' === $posts_layout ) ? array(
			'id'         => 'mts_featured_category_title_font_' . $unique_id,
			'type'       => 'typography',
			'title'      => esc_html__( 'Section Title Typography', 'fresh' ),
			'std'        => array(
				'preview-text'   => 'Title Font',
				'preview-color'  => 'light',
				'font-family'    => 'Open Sans',
				'font-weight'    => '700',
				'font-size'      => '22px',
				'color'          => '#494b46',
				'additional-css' => 'text-transform: uppercase;',
				'css-selectors'  => '.title-container.title-id-' . $unique_id . ' h3.featured-category-title',
			),
			'dependency' => $post_title_dependency,
		) : null,

		// Meta info.
		( 'layout-featured' === $posts_layout ) ? array(
			'id'    => 'post_meta_info_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Meta Info', 'fresh' ),
		) : null,

		array(
			'id'       => 'wrapper_bgcolor_' . $unique_id,
			'type'     => 'color',
			'title'    => esc_html__( 'Text background color', 'fresh' ),
			'sub_desc' => esc_html__( 'Select text background color.', 'fresh' ),
			'args'     => array( 'opacity' => true ),
			'std'      => 'rgba(153,192,52,0.9)',
		),

		( 'layout-featured' === $posts_layout ) ? array(
			'id'       => 'mts_home_headline_meta_info' . $unique_id,
			'type'     => 'layout2',
			// translators: title.
			'title'    => sprintf( wp_kses_post( __( '%s Meta Info', 'fresh' ) ), $title ),
			// translators: description.
			'sub_desc' => sprintf( wp_kses_post( __( 'Organize how you want the post meta info to appear on %s', 'fresh' ) ), $title ),
			'options'  => array(
				'enabled'  => array(
					'category' => array(
						'label'     => esc_html__( 'Categories', 'fresh' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_category_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'fresh' ),
							),
						),
					),
				),
				'disabled' => array(
					'author'  => array(
						'label'     => __( 'Author Name', 'fresh' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_author_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'fresh' ),
							),
						),
					),
					'date'    => array(
						'label'     => esc_html__( 'Date', 'fresh' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_date_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'fresh' ),
							),
						),
					),
					'comment' => array(
						'label'     => esc_html__( 'Comment Count', 'fresh' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_comment_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'fresh' ),
							),
						),
					),
				),
			),
			'std'      => array(
				'enabled'  => array(
					'category' => array(
						'label'     => esc_html__( 'Categories', 'fresh' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_category_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'fresh' ),
							),
						),
					),
				),
				'disabled' => array(
					'author'  => array(
						'label'     => __( 'Author Name', 'fresh' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_author_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'fresh' ),
							),
						),
					),
					'date'    => array(
						'label'     => esc_html__( 'Date', 'fresh' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_date_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'fresh' ),
							),
						),
					),
					'comment' => array(
						'label'     => esc_html__( 'Comment Count', 'fresh' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_comment_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'fresh' ),
							),
						),
					),
				),
			),
		) : null,

		( 'layout-featured' === $posts_layout ) ? array(
			'id'       => 'mts_meta_info_margin_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Margin', 'fresh' ),
			'sub_desc' => esc_html__( 'Post Meta Info margin.', 'fresh' ),
			'std'      => array(
				'top'    => '0',
				'right'  => '0',
				'bottom' => '6px',
				'left'   => '0',
			),
		) : null,
		( 'layout-featured' === $posts_layout ) ? array(
			'id'       => 'mts_meta_info_padding_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Padding', 'fresh' ),
			'sub_desc' => esc_html__( 'Post Meta Info padding.', 'fresh' ),
			'std'      => array(
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
				'left'   => '0',
			),
		) : null,

		( 'layout-featured' === $posts_layout ) ? array(
			'id'       => 'meta_info_border_' . $unique_id,
			'type'     => 'border',
			'title'    => esc_html__( 'Border', 'fresh' ),
			'sub_desc' => esc_html__( 'Select border.', 'fresh' ),
		) : null,

		( 'layout-featured' === $posts_layout ) ? array(
			'id'    => 'meta_info_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Meta Info Typography', 'fresh' ),
			'std'   => array(
				'preview-text'  => 'Post Meta Info Font',
				'preview-color' => 'light',
				'font-family'   => 'Open Sans',
				'font-weight'   => '400',
				'font-size'     => '16px',
				'color'         => '#e3ebd0',
				'css-selectors' => '.layout-' . $unique_id . ' .latestPost .post-info, .layout-' . $unique_id . ' .latestPost .post-info span a',
			),
		) : null,
		// Post Container.
		( 'layout-featured' === $posts_layout ) ? array(
			'id'    => 'mts_post_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Container', 'fresh' ),
		) : null,

		( 'layout-featured' === $posts_layout ) ? array(
			'id'       => 'mts_featured_category_background_' . $unique_id,
			'type'     => 'background',
			'title'    => esc_html__( 'Post Background Color', 'fresh' ),
			'sub_desc' => esc_html__( 'Set background color, pattern and image from here.', 'fresh' ),
			'options'  => array(
				'color'         => '',            // false to disable, not needed otherwise.
				'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
				'image_upload'  => '',            // false to disable, not needed otherwise.
				'repeat'        => array(),       // false to disable, array of options to override default ( optional ).
				'attachment'    => array(),       // false to disable, array of options to override default ( optional ).
				'position'      => array(),       // false to disable, array of options to override default ( optional ).
				'size'          => array(),       // false to disable, array of options to override default ( optional ).
				'gradient'      => '',            // false to disable, not needed otherwise.
				'parallax'      => array(),       // false to disable, array of options to override default ( optional ).
			),
			'std'      => array(
				'color'         => '',
				'use'           => 'pattern',
				'image_pattern' => 'nobg',
				'image_upload'  => '',
				'repeat'        => 'repeat',
				'attachment'    => 'scroll',
				'position'      => 'left top',
				'size'          => 'cover',
				'gradient'      => array(
					'from'      => '#ffffff',
					'to'        => '#000000',
					'direction' => '0deg',
				),
				'parallax'      => '0',
			),
		) : null,
		( 'layout-featured' === $posts_layout ) ? array(
			'id'       => 'post_border_' . $unique_id,
			'type'     => 'border',
			'title'    => esc_html__( 'Border', 'fresh' ),
			'sub_desc' => esc_html__( 'Select border', 'fresh' ),
		) : null,
		( 'layout-featured' === $posts_layout ) ? array(
			'id'       => 'post_margin_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Margin', 'fresh' ),
			'sub_desc' => esc_html__( 'Post margin.', 'fresh' ),
			'left'     => false,
			'right'    => false,
			'std'      => array(
				'top'    => '72px',
				'bottom' => '0',
			),
		) : null,
		( 'layout-featured' === $posts_layout ) ? array(
			'id'       => 'post_padding_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Padding', 'fresh' ),
			'sub_desc' => esc_html__( 'Post padding.', 'fresh' ),
			'std'      => array(
				'left'   => '0',
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
			),
		) : null,

		( 'layout-featured' === $posts_layout ) ? array(
			'id'    => 'post_title_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Title Font', 'fresh' ),
			'std'   => array(
				'preview-text'  => 'Post Title Font',
				'preview-color' => 'light',
				'font-family'   => 'Open Sans',
				'font-weight'   => '600',
				'font-size'     => '16px',
				'line-height'   => '22px',
				'color'         => '#ffffff',
				'css-selectors' => '.layout-' . $unique_id . ' .latestPost .title a',
			),
		) : null,

	);
endforeach;
